Transaction

Struct Transaction 

pub struct Transaction<'a, T: JsonRpcClient> {
    pub id: TxHash,
    /* private fields */
}
A high-level struct to manage a transaction.

This is the high-level representation of a transaction. It can be used to confirm a transaction.

Fields

id: TxHash

Hash of the transaction.

Implementations

Source

impl<'a, T: JsonRpcClient> Transaction<'a, T>

pub fn new(id: TxHash, client: &'a Provider<T>) -> Self

Creates a new Transaction.

To create a new transaction you need to pass a hash, which identifies a transaction uniquely, and a provider, which is used to confirm the transaction.

pub async fn confirm(&self) -> Result<GetTransactionResponse, Error>

Tries to confirm a transaction.

pub async fn try_confirm( &self, interval: Duration, max_attempt: u32, ) -> Result<GetTransactionResponse, Error>

The try_confirm function attempts to confirm a transaction by making repeated requests to a client, with a specified interval and maximum number of attempts, and returns the result.

Arguments:

  • interval: The interval parameter is the duration of time to wait between each attempt to confirm the transaction. It is of type tokio::time::Duration, which represents a duration of time in the Tokio runtime.
  • max_attempt: The max_attempt parameter is the maximum number of attempts to confirm the transaction.